@@ -1,16 +1,9 @@
 # ifndef CPPAD_CPPAD_HPP
 # define CPPAD_CPPAD_HPP
-/* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-20 Bradley M. Bell
-
-CppAD is distributed under the terms of the
-             Eclipse Public License Version 2.0.
-
-This Source Code may also be made available under the following
-Secondary License when the conditions for such availability set forth
-in the Eclipse Public License, Version 2.0 are satisfied:
-      GNU General Public License, Version 2.0 or later.
----------------------------------------------------------------------------- */
+// SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later
+// SPDX-FileCopyrightText: Bradley M. Bell <bradbell@seanet.com>
+// SPDX-FileContributor: 2003-22 Bradley M. Bell
+// ----------------------------------------------------------------------------
 /*!
 \file cppad.hpp
 \brief includes the entire CppAD package in the necessary order.
@@ -43,9 +36,6 @@ in the Eclipse Public License, Version 2.0 are satisfied:
 // vectors used with CppAD
 # include <cppad/core/testvector.hpp>
 
-// deprecated vectors used with CppAD
-# include <cppad/core/test_vector.hpp>
-
 // Declare classes and fucntions that are used before defined
 # include <cppad/local/declare_ad.hpp>
 
